@@ -1,7 +1,7 @@
 import abc
 from typing import Any, Generic, Set, TypeVar
 
-T = TypeVar("T")
+T = TypeVar('T')
 
 
 class UnexpectedCollision(Exception):
@@ -38,12 +38,12 @@ class HashBasedCollisionDetector(AbstractCollisionDetector[T]):
 
     def add_already_processed_event(self, obj: T) -> None:
         if _is_object_unhashable(obj):
-            raise UnhashableObjectError(f"Object {obj!r} is unhashable")
+            raise UnhashableObjectError(f'Object {obj!r} is unhashable')
         self.already_processed_object_hashes.add(hash(obj))
 
     def has_collision(self, obj: T) -> bool:
         if _is_object_unhashable(obj):
-            raise UnhashableObjectError(f"Object {obj!r} is unhashable")
+            raise UnhashableObjectError(f'Object {obj!r} is unhashable')
         return any(
             hash(obj) == processed_hash for processed_hash in self.already_processed_object_hashes
         )
