@@ -6,7 +6,7 @@ from glQiwiApi.qiwi.clients.wallet.types.balance import AvailableBalance
 
 
 class GetAvailableBalances(QiwiAPIMethod[List[AvailableBalance]]):
-    http_method: ClassVar[str] = "GET"
+    http_method: ClassVar[str] = 'GET'
     url: ClassVar[
         str
-    ] = "https://edge.qiwi.com/funding-sources/v2/persons/{phone_number}/accounts/offer"
+    ] = 'https://edge.qiwi.com/funding-sources/v2/persons/{phone_number}/accounts/offer'
