@@ -3,8 +3,8 @@ from typing import Any, Dict, TypeVar, cast
 
 from pydantic import BaseModel
 
-Model = TypeVar("Model", bound=BaseModel)
-DEFAULT_EXCLUDE = ("cls", "self", "__class__")
+Model = TypeVar('Model', bound=BaseModel)
+DEFAULT_EXCLUDE = ('cls', 'self', '__class__')
 
 
 def filter_dictionary_none_values(dictionary: Dict[Any, Any]) -> Dict[Any, Any]:
@@ -17,7 +17,7 @@ def filter_dictionary_none_values(dictionary: Dict[Any, Any]) -> Dict[Any, Any]:
 
 
 def make_payload(**kwargs: Any) -> Dict[Any, Any]:
-    exclude_list = kwargs.pop("exclude", ())
+    exclude_list = kwargs.pop('exclude', ())
     return {
         key: value
         for key, value in kwargs.items()
@@ -32,6 +32,6 @@ def parse_auth_link(response_data: str) -> str:
     :param response_data:
     """
     regexp = re.compile(
-        r"https://yoomoney.ru/oauth2/authorize[?]requestid[=]\w+"
+        r'https://yoomoney.ru/oauth2/authorize[?]requestid[=]\w+'
     )  # pragma: no cover
     return cast(str, re.findall(regexp, str(response_data))[0])  # pragma: no cover
